@@ -13,3 +13,10 @@ test_that("arguments", {
   expect_snapshot(translate_args(mixture %>% set_engine("glmnet")))
   expect_snapshot(translate_args(mixture_v %>% set_engine("glmnet")))
 })
+
+test_that("check_args() works", {
+  skip_if_not_installed("parsnip", "1.2.1.9001")
+
+  # Here for completeness, no checking is done
+  expect_true(TRUE)
+})
